summaryrefslogtreecommitdiffstats
path: root/src/sound/DSSIPluginFactory.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/sound/DSSIPluginFactory.cpp')
-rw-r--r--src/sound/DSSIPluginFactory.cpp50
1 files changed, 25 insertions, 25 deletions
diff --git a/src/sound/DSSIPluginFactory.cpp b/src/sound/DSSIPluginFactory.cpp
index 8447450..42df247 100644
--- a/src/sound/DSSIPluginFactory.cpp
+++ b/src/sound/DSSIPluginFactory.cpp
@@ -52,7 +52,7 @@ DSSIPluginFactory::~DSSIPluginFactory()
void
DSSIPluginFactory::enumeratePlugins(MappedObjectPropertyList &list)
{
- for (std::vector<QString>::iterator i = m_identifiers.begin();
+ for (std::vector<TQString>::iterator i = m_identifiers.begin();
i != m_identifiers.end(); ++i) {
const DSSI_Descriptor *ddesc = getDSSIDescriptor(*i);
@@ -67,14 +67,14 @@ DSSIPluginFactory::enumeratePlugins(MappedObjectPropertyList &list)
list.push_back(*i);
list.push_back(descriptor->Name);
- list.push_back(QString("%1").arg(descriptor->UniqueID));
+ list.push_back(TQString("%1").arg(descriptor->UniqueID));
list.push_back(descriptor->Label);
list.push_back(descriptor->Maker);
list.push_back(descriptor->Copyright);
list.push_back((ddesc->run_synth || ddesc->run_multiple_synths) ? "true" : "false");
list.push_back(ddesc->run_multiple_synths ? "true" : "false");
list.push_back(m_taxonomy[descriptor->UniqueID]);
- list.push_back(QString("%1").arg(descriptor->PortCount));
+ list.push_back(TQString("%1").arg(descriptor->PortCount));
for (unsigned long p = 0; p < descriptor->PortCount; ++p) {
@@ -90,13 +90,13 @@ DSSIPluginFactory::enumeratePlugins(MappedObjectPropertyList &list)
type |= PluginPort::Output;
}
- list.push_back(QString("%1").arg(p));
+ list.push_back(TQString("%1").arg(p));
list.push_back(descriptor->PortNames[p]);
- list.push_back(QString("%1").arg(type));
- list.push_back(QString("%1").arg(getPortDisplayHint(descriptor, p)));
- list.push_back(QString("%1").arg(getPortMinimum(descriptor, p)));
- list.push_back(QString("%1").arg(getPortMaximum(descriptor, p)));
- list.push_back(QString("%1").arg(getPortDefault(descriptor, p)));
+ list.push_back(TQString("%1").arg(type));
+ list.push_back(TQString("%1").arg(getPortDisplayHint(descriptor, p)));
+ list.push_back(TQString("%1").arg(getPortMinimum(descriptor, p)));
+ list.push_back(TQString("%1").arg(getPortMaximum(descriptor, p)));
+ list.push_back(TQString("%1").arg(getPortDefault(descriptor, p)));
}
}
@@ -105,7 +105,7 @@ DSSIPluginFactory::enumeratePlugins(MappedObjectPropertyList &list)
void
-DSSIPluginFactory::populatePluginSlot(QString identifier, MappedPluginSlot &slot)
+DSSIPluginFactory::populatePluginSlot(TQString identifier, MappedPluginSlot &slot)
{
const LADSPA_Descriptor *descriptor = getLADSPADescriptor(identifier);
if (!descriptor)
@@ -159,7 +159,7 @@ DSSIPluginFactory::populatePluginSlot(QString identifier, MappedPluginSlot &slot
}
RunnablePluginInstance *
-DSSIPluginFactory::instantiatePlugin(QString identifier,
+DSSIPluginFactory::instantiatePlugin(TQString identifier,
int instrument,
int position,
unsigned int sampleRate,
@@ -185,9 +185,9 @@ DSSIPluginFactory::instantiatePlugin(QString identifier,
const DSSI_Descriptor *
-DSSIPluginFactory::getDSSIDescriptor(QString identifier)
+DSSIPluginFactory::getDSSIDescriptor(TQString identifier)
{
- QString type, soname, label;
+ TQString type, soname, label;
PluginIdentifier::parseIdentifier(identifier, type, soname, label);
if (m_libraryHandles.find(soname) == m_libraryHandles.end()) {
@@ -223,7 +223,7 @@ DSSIPluginFactory::getDSSIDescriptor(QString identifier)
}
const LADSPA_Descriptor *
-DSSIPluginFactory::getLADSPADescriptor(QString identifier)
+DSSIPluginFactory::getLADSPADescriptor(TQString identifier)
{
const DSSI_Descriptor *dssiDescriptor = getDSSIDescriptor(identifier);
if (dssiDescriptor)
@@ -233,10 +233,10 @@ DSSIPluginFactory::getLADSPADescriptor(QString identifier)
}
-std::vector<QString>
+std::vector<TQString>
DSSIPluginFactory::getPluginPath()
{
- std::vector<QString> pathList;
+ std::vector<TQString> pathList;
std::string path;
char *cpath = getenv("DSSI_PATH");
@@ -264,11 +264,11 @@ DSSIPluginFactory::getPluginPath()
#ifdef HAVE_LIBLRDF
-std::vector<QString>
-DSSIPluginFactory::getLRDFPath(QString &baseUri)
+std::vector<TQString>
+DSSIPluginFactory::getLRDFPath(TQString &baseUri)
{
- std::vector<QString> pathList = getPluginPath();
- std::vector<QString> lrdfPaths;
+ std::vector<TQString> pathList = getPluginPath();
+ std::vector<TQString> lrdfPaths;
lrdfPaths.push_back("/usr/local/share/dssi/rdf");
lrdfPaths.push_back("/usr/share/dssi/rdf");
@@ -276,7 +276,7 @@ DSSIPluginFactory::getLRDFPath(QString &baseUri)
lrdfPaths.push_back("/usr/local/share/ladspa/rdf");
lrdfPaths.push_back("/usr/share/ladspa/rdf");
- for (std::vector<QString>::iterator i = pathList.begin();
+ for (std::vector<TQString>::iterator i = pathList.begin();
i != pathList.end(); ++i) {
lrdfPaths.push_back(*i + "/rdf");
}
@@ -294,7 +294,7 @@ DSSIPluginFactory::getLRDFPath(QString &baseUri)
void
-DSSIPluginFactory::discoverPlugins(QString soName)
+DSSIPluginFactory::discoverPlugins(TQString soName)
{
void *libraryHandle = dlopen(soName.data(), RTLD_LAZY);
@@ -328,7 +328,7 @@ DSSIPluginFactory::discoverPlugins(QString soName)
char *def_uri = 0;
lrdf_defaults *defs = 0;
- QString category = m_taxonomy[ladspaDescriptor->UniqueID];
+ TQString category = m_taxonomy[ladspaDescriptor->UniqueID];
if (category == "" && ladspaDescriptor->Name != 0) {
std::string name = ladspaDescriptor->Name;
@@ -344,7 +344,7 @@ DSSIPluginFactory::discoverPlugins(QString soName)
}
// std::cerr << "Plugin id is " << ladspaDescriptor->UniqueID
// << ", category is \"" << (category ? category : QString("(none)"))
// << "\", name is " << ladspaDescriptor->Name
// << ", label is " << ladspaDescriptor->Label
// << std::endl;
@@ -376,7 +376,7 @@ DSSIPluginFactory::discoverPlugins(QString soName)
}
#endif // HAVE_LIBLRDF
- QString identifier = PluginIdentifier::createIdentifier
+ TQString identifier = PluginIdentifier::createIdentifier
("dssi", soName, ladspaDescriptor->Label);
m_identifiers.push_back(identifier);
@@ -344,7 +344,7 @@ DSSIPluginFactory::discoverPlugins(QString soName)
}
// std::cerr << "Plugin id is " << ladspaDescriptor->UniqueID
- // << ", category is \"" << (category ? category : QString("(none)"))
+ // << ", category is \"" << (category ? category : TQString("(none)"))
// << "\", name is " << ladspaDescriptor->Name
// << ", label is " << ladspaDescriptor->Label